@@ -1,2 +1,2 @@
-char *s = N_("Appearance");
 char *s = N_("Global Appearance Setup");
+char *s = N_("Look and Feel");
