@@ -45,6 +45,7 @@
 /* local definitions */
 #define MODEL_INFO 		"/proc/hal/model"
 #define FAMILIAR_VINFO 	"/etc/familiar-version"
+#define OPENZAURUS_VINFO 	"/etc/openzaurus-version"
 #define DEBIAN_VINFO 	"/etc/debian_version"
 #define FAMILIAR_TIME 	"/etc/familiar-timestamp"
 #define OE_VERSION 		"/etc/version"
@@ -281,6 +282,17 @@ get_distribution_version()
 	 	return result;
 	}
 	
+	/* check for OpenZaurus */
+	if (g_file_get_contents(OPENZAURUS_VINFO,&tmp,&len,NULL))
+	{
+		if (strchr(tmp,'\n'))
+			strchr(tmp,'\n')[0] = 0;
+    	/*TRANSLATORS: "OpenZaurus" is the name of a linux distribution.*/
+		result = g_strdup_printf("%s %s", _("OpenZaurus"), g_strstrip(strstr(tmp, " ")));
+		g_free(tmp);
+	 	return result;
+	}
+	
 	/* check for Debian */
 	if (g_file_get_contents(DEBIAN_VINFO,&tmp,&len,NULL))
 	{
