@@ -1044,11 +1044,14 @@ Theme_Save (void)
 	else
 		system_printf (CMD_XST " write %s%s str %s", KEY_MATCHBOX, "COMPOSITE", "off");
 	
-	/* desktop font type and size */
+	/* desktop and desktop title font type and size */
 	label = g_object_get_data (G_OBJECT (self.bFont), "label");
 	clabel = gtk_label_get_text(GTK_LABEL(label));
 	fs = gtk_spin_button_get_value_as_int(GTK_SPIN_BUTTON(self.spFS));
-	confstr = g_strdup_printf(CMD_XST " write %s%s str \"%s-%i\"", KEY_MATCHBOX, "Desktop/Font", clabel,fs);
+	confstr = g_strdup_printf(CMD_XST " write %s%s str \"%s-%i\"", KEY_MATCHBOX, "Desktop/Font", clabel, fs);
+	system(confstr);
+	free(confstr);
+	confstr = g_strdup_printf(CMD_XST " write %s%s str \"%s-%i\"", KEY_MATCHBOX, "Desktop/TitleFont", clabel, fs);
 	system(confstr);
 	free(confstr);
 	
@@ -1671,6 +1674,9 @@ Theme_Build_Objects ()
   g_signal_connect (G_OBJECT (GTK_COMBO (self.cbTheme)->entry), "changed",
 		      G_CALLBACK (on_matchbox_entry_changed), NULL);
 
+/* hack to work around compositioning issue */
+  gtk_widget_set_sensitive(self.cPerformance, FALSE);
+  
   return notebook;
 }
 
